@@ -4,7 +4,7 @@ import requests
 import getpass
 
 # URL = "http://localhost:5000"
-URL = "shubbansal27.pythonanywhere.com"
+URL = "http://shubbansal27.pythonanywhere.com"
 
 endpoint1 = URL + "/authenticate_pipclient"
 endpoint2 = URL + "/submit_code_pip_module"
